@@ -527,6 +527,8 @@ totem_embedded_do_command (TotemEmbedded *embedded,
 {
 	g_return_val_if_fail (command != NULL, FALSE);
 
+	g_message ("totem_embedded_do_command: %s", command);
+
 	if (strcmp (command, TOTEM_COMMAND_PLAY) == 0) {
 		return totem_embedded_play (embedded, error);
 	}
@@ -550,6 +552,9 @@ totem_embedded_set_href (TotemEmbedded *embedded,
 			 const char *target,
 			 GError *error)
 {
+	g_message ("totem_embedded_set_href %s (target: %s)",
+		   href_uri, target);
+
 	g_free (embedded->href_uri);
 	g_free (embedded->target);
 
@@ -683,6 +688,8 @@ totem_pl_item_free (gpointer data, gpointer user_data)
 static gboolean
 totem_embedded_clear_playlist (TotemEmbedded *emb, GError *error)
 {
+	g_message ("totem_embedded_clear_playlist");
+
 	g_list_foreach (emb->playlist, (GFunc) totem_pl_item_free, NULL);
 	g_list_free (emb->playlist);
 
@@ -823,6 +830,8 @@ static gboolean
 totem_embedded_close_stream (TotemEmbedded *emb,
 			     GError *error)
 {
+	g_message ("totem_embedded_close_stream");
+
 	if (!emb->is_browser_stream)
 		return TRUE;
 
@@ -890,7 +899,8 @@ totem_embedded_set_local_file (TotemEmbedded *emb,
 {
 	char *file_uri;
 
-	g_message ("Setting the current path to %s", path);
+	g_message ("Setting the current path to %s (uri: %s base: %s)",
+		   path, uri, base_uri);
 
 	totem_embedded_clear_playlist (emb, NULL);
 
@@ -912,6 +922,8 @@ totem_embedded_set_local_cache (TotemEmbedded *emb,
 {
 	int fd;
 
+	g_message ("totem_embedded_set_local_cache: %s", path);
+
 	/* FIXME Should also handle playlists */
 	if (!emb->is_browser_stream)
 		return TRUE;
@@ -944,8 +956,8 @@ totem_embedded_set_playlist (TotemEmbedded *emb,
 	GFile *src, *dst;
 	int fd;
 
-	g_message ("Setting the current playlist to %s (base: %s)",
-		   path, base_uri);
+	g_message ("Setting the current playlist to %s (uri: %s base: %s)",
+		   path, uri, base_uri);
 
 	totem_embedded_clear_playlist (emb, NULL);
 
@@ -1144,7 +1156,9 @@ on_copy_location1_activate (GtkButton *button, TotemEmbedded *emb)
 	GtkClipboard *clip;
 	const char *uri;
 
-	if (emb->href_uri != NULL) {
+	if (emb->stream_uri != NULL) {
+		uri = emb->stream_uri;
+	} else if (emb->href_uri != NULL) {
 		uri = emb->href_uri;
 	} else {
 		uri = emb->current_uri;
@@ -1261,6 +1275,16 @@ on_popup_button_button_pressed (GtkToggleButton *button,
 	return FALSE;
 }
 
+static void
+on_popup_menu_unmap (GtkWidget *menu,
+		     TotemEmbedded *emb)
+{
+	GtkWidget *button;
+
+	button = GTK_WIDGET (gtk_builder_get_object (emb->xml, "popup_button"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
+}
+
 static char *
 resolve_redirect (const char *old_mrl, const char *mrl)
 {
@@ -1587,6 +1611,13 @@ property_notify_cb_volume (BaconVideoWidget *bvw,
 static gboolean
 on_seek_start (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 {
+	/* HACK: we want the behaviour you get with the middle button, so we
+	 * mangle the event.  clicking with other buttons moves the slider in
+	 * step increments, clicking with the middle button moves the slider to
+	 * the location of the click.
+	 */
+	event->button = 2;
+
 	emb->seeking = TRUE;
 	totem_time_label_set_seeking (TOTEM_TIME_LABEL (emb->fs->time_label),
 				      TRUE);
@@ -1597,6 +1628,9 @@ on_seek_start (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 static gboolean
 cb_on_seek (GtkWidget *widget, GdkEventButton *event, TotemEmbedded *emb)
 {
+	/* HACK: see on_seek_start */
+	event->button = 2;
+
 	bacon_video_widget_seek (emb->bvw,
 		gtk_range_get_value (GTK_RANGE (widget)) / 65535, NULL);
 	totem_time_label_set_seeking (TOTEM_TIME_LABEL (emb->fs->time_label),
@@ -1704,6 +1738,7 @@ totem_embedded_construct (TotemEmbedded *emb,
 {
 	GtkWidget *child, *container, *image;
 	GtkWidget *popup_button;
+	GtkWidget *menu;
 	BvwUseType type;
 	GError *err = NULL;
 	GConfClient *gc;
@@ -1909,6 +1944,10 @@ totem_embedded_construct (TotemEmbedded *emb,
 					     GTK_WINDOW (emb->window), emb);
 	g_assert (emb->menuxml);
 
+	menu = GTK_WIDGET (gtk_builder_get_object (emb->menuxml, "menu"));
+	g_signal_connect (G_OBJECT (menu), "unmap",
+			  G_CALLBACK (on_popup_menu_unmap), emb);
+
 	/* Set the logo and the button glow */
 	if (!emb->hidden && emb->autostart == FALSE) {
 		totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), TRUE);
