@@ -257,6 +257,7 @@ class totemPlugin {
 #ifdef TOTEM_GMP_PLUGIN
   public:
     void SetURL (const char* aURL);
+    void SetBaseURL (const char* aBaseURL);
     const char* URL() const { return mURLURI; }
 
   private:
@@ -267,6 +268,7 @@ class totemPlugin {
   public:
     bool SetQtsrc (const char* aURL);
     bool SetHref (const char* aURL);
+    void SetURL (const NPString&);
 
     const char* QtSrc () const { return mQtsrcURI; }
     const char* Href () const { return mHref; }
